//Source file: UICollectCriteria.java
//Date: June 2005
//User Interaction Data Types for 3GPP TS 29.198-05 V5.10.0

package org.csapi.jr.se.ui;

/**
 * Defines the Sequence of Data Elements that specify the additional properties for the collection of information, such as the end character, first character timeout, inter-character timeout, and maximum interaction time. 
Input is considered successful if the following applies:
If the EndSequence is not present (that is an empty string):
-	when the InterCharTimeOut timer expires; or
-	when the number of valid digits received equals the MaxLength.
If the EndSequence is present:
-	when the InterCharTimeOut timer expires; or
-	when the EndSequence is received; or
-	when the number of valid digits received equals the MaxLength.
In the case the number of valid characters received is less than the MinLength when the InterCharTimeOut timer expires or when the EndSequence is received, the input is considered erroneous. 
The collected characters (including the EndSequence) are sent to the client application when input has been successful.
 * 
 */
public final class UICollectCriteria implements java.io.Serializable {

    private int minLength;
    private int maxLength;
    private String endSequence;
    private int startTimeout;
    private int interCharTimeout;

    /**
     * Creates a new UICollectCriteria instance.
     */
    public UICollectCriteria () {}

    /**
     * Creates a new UICollectCriteria instance.
     * @param _minLength   Defines the minimum number of characters (for example digits) to collect. 
     * @param _maxLength   Defines the maximum number of characters (for example digits) to collect.
     * @param _endSequence   Defines the character or characters which terminate an input of variable length, for example phone numbers.
     * @param _startTimeout   Specifies the value for the first character time-out timer. The timer is started when the announcement has been completed or has been interrupted. The user should enter the start of the response (for example first digit) before the timer expires. If the start of the response is not entered before the timer expires, the input is regarded to be erroneous. After receipt of the start of the response, which may be valid or invalid, the timer is stopped.
     * @param _interCharTimeout   Specifies the value for the inter-character time-out timer. The timer is started when a response (for example digit) is received, and is reset and restarted when a subsequent response is received. The responses may be valid or invalid. the announcement has been completed or has been interrupted.
     */
    public UICollectCriteria (int _minLength, int _maxLength, String _endSequence, int _startTimeout, int _interCharTimeout) {

        this.minLength = _minLength;
        this.maxLength = _maxLength;
        this.endSequence = _endSequence;
        this.startTimeout = _startTimeout;
        this.interCharTimeout = _interCharTimeout;
    }

    /**
     * This method returns a minLength.
     * 
     * @return a int value
     */
    public int getMinLength() {
        return minLength;
    }

    /**
     * This method returns a maxLength.
     * 
     * @return a int value
     */
    public int getMaxLength() {
        return maxLength;
    }

    /**
     * This method returns a endSequence.
     * 
     * @return a String value
     */
    public String getEndSequence() {
        return endSequence;
    }

    /**
     * This method returns a startTimeout.
     * 
     * @return a int value
     */
    public int getStartTimeout() {
        return startTimeout;
    }

    /**
     * This method returns a interCharTimeout.
     * 
     * @return a int value
     */
    public int getInterCharTimeout() {
        return interCharTimeout;
    }


    /**
     * This method sets a minLength.
     */ 
    public void setMinLength(int minLength) {
        this.minLength = minLength;
    }

    /**
     * This method sets a maxLength.
     */ 
    public void setMaxLength(int maxLength) {
        this.maxLength = maxLength;
    }

    /**
     * This method sets a endSequence.
     */ 
    public void setEndSequence(String endSequence) {
        this.endSequence = endSequence;
    }

    /**
     * This method sets a startTimeout.
     */ 
    public void setStartTimeout(int startTimeout) {
        this.startTimeout = startTimeout;
    }

    /**
     * This method sets a interCharTimeout.
     */ 
    public void setInterCharTimeout(int interCharTimeout) {
        this.interCharTimeout = interCharTimeout;
    }


    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof UICollectCriteria)) {
            return false;
        } 
        UICollectCriteria uICollectCriteria = (UICollectCriteria) o;
        if(!(this.minLength == uICollectCriteria.minLength)) {
            return false;
        }
        if(!(this.maxLength == uICollectCriteria.maxLength)) {
            return false;
        }
        if ((this.endSequence != null) && (uICollectCriteria.endSequence != null)) {
            if(!(this.endSequence.equals(uICollectCriteria.endSequence)))  {
                return false;
            }
        }
        if(!(this.startTimeout == uICollectCriteria.startTimeout)) {
            return false;
        }
        if(!(this.interCharTimeout == uICollectCriteria.interCharTimeout)) {
            return false;
        }
        if (this.hashCode() != o.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // UICollectCriteria

