//Source file: UIError.java
//Date: June 2005
//User Interaction Data Types for 3GPP TS 29.198-05 V5.10.0

package org.csapi.jr.se.ui;

/**
 * Defines the UI error codes.
The call User Interaction object will be automatically de-assigned if the error P_UI_ERROR_ABANDON is reported, as a corresponding call or call leg object no longer exists. 
 *
 */
public final class UIError implements java.io.Serializable {

    private int _value;
    private static int _size = 10;
    private static UIError[] _array = new UIError[_size];

    /**
     * Private constructor used internally to construct static objects 
     */
    private UIError(int value) {
        _value = value;
        _array[_value] = this;
    }

    /**
     * Undefined error
     */
    public static final int _UI_ERROR_UNDEFINED =  0;

    /**
     * Undefined error
     */
    public static final UIError UI_ERROR_UNDEFINED = new UIError(_UI_ERROR_UNDEFINED);

    /**
     * The specified information (InfoId, InfoData, or InfoAddress) is invalid
     */
    public static final int _UI_ERROR_ILLEGAL_INFO =  1;

    /**
     * The specified information (InfoId, InfoData, or InfoAddress) is invalid
     */
    public static final UIError UI_ERROR_ILLEGAL_INFO = new UIError(_UI_ERROR_ILLEGAL_INFO);

    /**
     * A legal InfoId is not known to the User Interaction service
     */
    public static final int _UI_ERROR_ID_NOT_FOUND =  2;

    /**
     * A legal InfoId is not known to the User Interaction service
     */
    public static final UIError UI_ERROR_ID_NOT_FOUND = new UIError(_UI_ERROR_ID_NOT_FOUND);

    /**
     * The information resources used by the User Interaction service are unavailable, for example due to an overload situation.
     */
    public static final int _UI_ERROR_RESOURCE_UNAVAILABLE =  3;

    /**
     * The information resources used by the User Interaction service are unavailable, for example due to an overload situation.
     */
    public static final UIError UI_ERROR_RESOURCE_UNAVAILABLE = new UIError(_UI_ERROR_RESOURCE_UNAVAILABLE);

    /**
     * The values for minimum and maximum collection length are out of range
     */
    public static final int _UI_ERROR_ILLEGAL_RANGE =  4;

    /**
     * The values for minimum and maximum collection length are out of range
     */
    public static final UIError UI_ERROR_ILLEGAL_RANGE = new UIError(_UI_ERROR_ILLEGAL_RANGE);

    /**
     * Improper user response
     */
    public static final int _UI_ERROR_IMPROPER_USER_RESPONSE =  5;

    /**
     * Improper user response
     */
    public static final UIError UI_ERROR_IMPROPER_USER_RESPONSE = new UIError(_UI_ERROR_IMPROPER_USER_RESPONSE);

    /**
     * The specified leg is disconnected before the send information completed
     */
    public static final int _UI_ERROR_ABANDON =  6;

    /**
     * The specified leg is disconnected before the send information completed
     */
    public static final UIError UI_ERROR_ABANDON = new UIError(_UI_ERROR_ABANDON);

    /**
     * There is no active User Interaction for the specified leg. Either the application did not start any User Interaction or the User Interaction was already finished when the abortActionReq() was called.
     */
    public static final int _UI_ERROR_NO_OPERATION_ACTIVE =  7;

    /**
     * There is no active User Interaction for the specified leg. Either the application did not start any User Interaction or the User Interaction was already finished when the abortActionReq() was called.
     */
    public static final UIError UI_ERROR_NO_OPERATION_ACTIVE = new UIError(_UI_ERROR_NO_OPERATION_ACTIVE);

    /**
     * There is no more storage capacity to record the message when the recordMessageReq() operation was called
     */
    public static final int _UI_ERROR_NO_SPACE_AVAILABLE =  8;

    /**
     * There is no more storage capacity to record the message when the recordMessageReq() operation was called
     */
    public static final UIError UI_ERROR_NO_SPACE_AVAILABLE = new UIError(_UI_ERROR_NO_SPACE_AVAILABLE);

    /**
     * The request has been accepted by the resource but it did not report a result.
     */
    public static final int _UI_ERROR_RESOURCE_TIMEOUT =  9;

    /**
     * The request has been accepted by the resource but it did not report a result.
     */
    public static final UIError UI_ERROR_RESOURCE_TIMEOUT = new UIError(_UI_ERROR_RESOURCE_TIMEOUT);


    /**
     * Method allows class to replace/resolve the object read from the stream before it 
     * is returned to the caller. By implementing this method, a class can directly control
     * the types and instances of its own instances being deserialized.
     *
     * @return the resolved UIError object 
     */
    private Object readResolve() throws java.io.ObjectStreamException {
        return _array[_value];
    }

    /**
     * Number representing enum type
     *
     * @return int number representing type of object, this is defined within the class
     */
    public int getValue() {
        return _value;
    }

    /**
     * getValueText method, overrides the getValueText() method in class java.lang.Object
     *
     * @return String  The stringified version of the UIError object
     */
    public String getValueText() {
        switch (_value) {
            case _UI_ERROR_UNDEFINED:
                return "UI_ERROR_UNDEFINED";
            case _UI_ERROR_ILLEGAL_INFO:
                return "UI_ERROR_ILLEGAL_INFO";
            case _UI_ERROR_ID_NOT_FOUND:
                return "UI_ERROR_ID_NOT_FOUND";
            case _UI_ERROR_RESOURCE_UNAVAILABLE:
                return "UI_ERROR_RESOURCE_UNAVAILABLE";
            case _UI_ERROR_ILLEGAL_RANGE:
                return "UI_ERROR_ILLEGAL_RANGE";
            case _UI_ERROR_IMPROPER_USER_RESPONSE:
                return "UI_ERROR_IMPROPER_USER_RESPONSE";
            case _UI_ERROR_ABANDON:
                return "UI_ERROR_ABANDON";
            case _UI_ERROR_NO_OPERATION_ACTIVE:
                return "UI_ERROR_NO_OPERATION_ACTIVE";
            case _UI_ERROR_NO_SPACE_AVAILABLE:
                return "UI_ERROR_NO_SPACE_AVAILABLE";
            case _UI_ERROR_RESOURCE_TIMEOUT:
                return "UI_ERROR_RESOURCE_TIMEOUT";
            default:
                return "ERROR";
        }
    }

    /**
     * Accepts values in the range of 0 to 9
     *
     * @param value number representing type of object, this is defined within the class
     * @throws org.csapi.jr.se.InvalidEnumValueException thrown if invalid value is passed into method
     */
    public static UIError getObject(int value) throws org.csapi.jr.se.InvalidEnumValueException {
        if(value >= 0 && value < _size) {
            return _array[value];
        } else {
            throw new org.csapi.jr.se.InvalidEnumValueException("value [" + value +" ] out of range");
        }
    }

    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof UIError)) {
            return false;
        }
        UIError uIError = (UIError) o; 
        if(!(this.getValue() == uIError.getValue())) {
            return false;
        }
        if (this.hashCode() != uIError.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // UIError

