//Source file: UIFault.java
//Date: June 2005
//User Interaction Data Types for 3GPP TS 29.198-05 V5.10.0

package org.csapi.jr.se.ui;

/**
 * Defines the cause of the UI fault detected.
 *
 */
public final class UIFault implements java.io.Serializable {

    private int _value;
    private static int _size = 2;
    private static UIFault[] _array = new UIFault[_size];

    /**
     * Private constructor used internally to construct static objects 
     */
    private UIFault(int value) {
        _value = value;
        _array[_value] = this;
    }

    /**
     * Undefined.
     */
    public static final int _UI_FAULT_UNDEFINED =  0;

    /**
     * Undefined.
     */
    public static final UIFault UI_FAULT_UNDEFINED = new UIFault(_UI_FAULT_UNDEFINED);

    /**
     * The related Call object has been terminated. Therefore, the UICall object is also terminated. No further interaction is possible with this object.
     */
    public static final int _UI_CALL_ENDED =  1;

    /**
     * The related Call object has been terminated. Therefore, the UICall object is also terminated. No further interaction is possible with this object.
     */
    public static final UIFault UI_CALL_ENDED = new UIFault(_UI_CALL_ENDED);


    /**
     * Method allows class to replace/resolve the object read from the stream before it 
     * is returned to the caller. By implementing this method, a class can directly control
     * the types and instances of its own instances being deserialized.
     *
     * @return the resolved UIFault object 
     */
    private Object readResolve() throws java.io.ObjectStreamException {
        return _array[_value];
    }

    /**
     * Number representing enum type
     *
     * @return int number representing type of object, this is defined within the class
     */
    public int getValue() {
        return _value;
    }

    /**
     * getValueText method, overrides the getValueText() method in class java.lang.Object
     *
     * @return String  The stringified version of the UIFault object
     */
    public String getValueText() {
        switch (_value) {
            case _UI_FAULT_UNDEFINED:
                return "UI_FAULT_UNDEFINED";
            case _UI_CALL_ENDED:
                return "UI_CALL_ENDED";
            default:
                return "ERROR";
        }
    }

    /**
     * Accepts values in the range of 0 to 1
     *
     * @param value number representing type of object, this is defined within the class
     * @throws org.csapi.jr.se.InvalidEnumValueException thrown if invalid value is passed into method
     */
    public static UIFault getObject(int value) throws org.csapi.jr.se.InvalidEnumValueException {
        if(value >= 0 && value < _size) {
            return _array[value];
        } else {
            throw new org.csapi.jr.se.InvalidEnumValueException("value [" + value +" ] out of range");
        }
    }

    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof UIFault)) {
            return false;
        }
        UIFault uIFault = (UIFault) o; 
        if(!(this.getValue() == uIFault.getValue())) {
            return false;
        }
        if (this.hashCode() != uIFault.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // UIFault

