//Source file: UIMessageCriteria.java
//Date: June 2005
//User Interaction Data Types for 3GPP TS 29.198-05 V5.10.0

package org.csapi.jr.se.ui;

/**
 * Defines the Sequence of Data Elements that specify the additional properties for the recording of a message.
 * 
 */
public final class UIMessageCriteria implements java.io.Serializable {

    private String endSequence;
    private int maxMessageTime;
    private int maxMessageSize;

    /**
     * Creates a new UIMessageCriteria instance.
     */
    public UIMessageCriteria () {}

    /**
     * Creates a new UIMessageCriteria instance.
     * @param _endSequence   Defines the character or characters which terminate an input of variable length, for example phone numbers.
     * @param _maxMessageTime   Specifies the maximum duration in seconds of the message that is to be recorded.
     * @param _maxMessageSize   If this parameter is non-zero, it specifies the maximum size in bytes of the message that is to be recorded.
     */
    public UIMessageCriteria (String _endSequence, int _maxMessageTime, int _maxMessageSize) {

        this.endSequence = _endSequence;
        this.maxMessageTime = _maxMessageTime;
        this.maxMessageSize = _maxMessageSize;
    }

    /**
     * This method returns a endSequence.
     * 
     * @return a String value
     */
    public String getEndSequence() {
        return endSequence;
    }

    /**
     * This method returns a maxMessageTime.
     * 
     * @return a int value
     */
    public int getMaxMessageTime() {
        return maxMessageTime;
    }

    /**
     * This method returns a maxMessageSize.
     * 
     * @return a int value
     */
    public int getMaxMessageSize() {
        return maxMessageSize;
    }


    /**
     * This method sets a endSequence.
     */ 
    public void setEndSequence(String endSequence) {
        this.endSequence = endSequence;
    }

    /**
     * This method sets a maxMessageTime.
     */ 
    public void setMaxMessageTime(int maxMessageTime) {
        this.maxMessageTime = maxMessageTime;
    }

    /**
     * This method sets a maxMessageSize.
     */ 
    public void setMaxMessageSize(int maxMessageSize) {
        this.maxMessageSize = maxMessageSize;
    }


    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof UIMessageCriteria)) {
            return false;
        } 
        UIMessageCriteria uIMessageCriteria = (UIMessageCriteria) o;
        if ((this.endSequence != null) && (uIMessageCriteria.endSequence != null)) {
            if(!(this.endSequence.equals(uIMessageCriteria.endSequence)))  {
                return false;
            }
        }
        if(!(this.maxMessageSize == uIMessageCriteria.maxMessageSize)) {
            return false;
        }
        if(!(this.maxMessageTime == uIMessageCriteria.maxMessageTime)) {
            return false;
        }
        if (this.hashCode() != o.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // UIMessageCriteria

