//Source file: UITargetObject.java
//Date: June 2005
//User Interaction Data Types for 3GPP TS 29.198-05 V5.10.0

package org.csapi.jr.se.ui;

/**
 * Defines the Tagged Choice of Data Elements that specify the object to perform User Interaction on.
 *
 */
public final class UITargetObject implements java.io.Serializable {

    private UITargetObjectType _discriminator = null;
    private java.lang.Object _object;

    /**
     * Creates a new UITargetObject.
     * Tagged choice of data elements always have empty constructors
     */ 
    public UITargetObject() {}

    /**
     * This method returns the discriminator.
     * 
     * @return a UITargetObjectType value 
     * @exception InvalidUnionAccessorException if an error occurs 
     */ 
    public UITargetObjectType getDiscriminator() throws org.csapi.jr.se.InvalidUnionAccessorException {
        if (_discriminator == null) {
            throw new org.csapi.jr.se.InvalidUnionAccessorException();
        }
        return _discriminator;
    }

    /**
     * This method returns a Call
     * 
     * @return  a org.csapi.jr.se.cc.gccs.Call value
     * @exception InvalidUnionAccessorException if an error occurs 
     */
    public org.csapi.jr.se.cc.gccs.Call getCall() throws org.csapi.jr.se.InvalidUnionAccessorException {
        if (_discriminator != UITargetObjectType.UI_TARGET_OBJECT_CALL) {
            throw new org.csapi.jr.se.InvalidUnionAccessorException();
        }
        return ((org.csapi.jr.se.cc.gccs.Call) _object);
    }

    /**
     * This method sets a Call
     * 
     * @param value a org.csapi.jr.se.cc.gccs.Call value
     */
    public void setCall(org.csapi.jr.se.cc.gccs.Call value) {
        _discriminator = UITargetObjectType.UI_TARGET_OBJECT_CALL;
        _object = value;
    }

    /**
     * This method returns a MultiPartyCall
     * 
     * @return  a org.csapi.jr.se.cc.mpccs.MultiPartyCall value
     * @exception InvalidUnionAccessorException if an error occurs 
     */
    public org.csapi.jr.se.cc.mpccs.MultiPartyCall getMultiPartyCall() throws org.csapi.jr.se.InvalidUnionAccessorException {
        if (_discriminator != UITargetObjectType.UI_TARGET_OBJECT_MULTI_PARTY_CALL) {
            throw new org.csapi.jr.se.InvalidUnionAccessorException();
        }
        return ((org.csapi.jr.se.cc.mpccs.MultiPartyCall) _object);
    }

    /**
     * This method sets a MultiPartyCall
     * 
     * @param value a org.csapi.jr.se.cc.mpccs.MultiPartyCall value
     */
    public void setMultiPartyCall(org.csapi.jr.se.cc.mpccs.MultiPartyCall value) {
        _discriminator = UITargetObjectType.UI_TARGET_OBJECT_MULTI_PARTY_CALL;
        _object = value;
    }

    /**
     * This method returns a CallLeg
     * 
     * @return  a org.csapi.jr.se.cc.mpccs.CallLeg value
     * @exception InvalidUnionAccessorException if an error occurs 
     */
    public org.csapi.jr.se.cc.mpccs.CallLeg getCallLeg() throws org.csapi.jr.se.InvalidUnionAccessorException {
        if (_discriminator != UITargetObjectType.UI_TARGET_OBJECT_CALL_LEG) {
            throw new org.csapi.jr.se.InvalidUnionAccessorException();
        }
        return ((org.csapi.jr.se.cc.mpccs.CallLeg) _object);
    }

    /**
     * This method sets a CallLeg
     * 
     * @param value a org.csapi.jr.se.cc.mpccs.CallLeg value
     */
    public void setCallLeg(org.csapi.jr.se.cc.mpccs.CallLeg value) {
        _discriminator = UITargetObjectType.UI_TARGET_OBJECT_CALL_LEG;
        _object = value;
    }


    /**
     * This method will receive the discriminator as a parameter and will set _object to null
     * 
     * @param discriminator a UITargetObjectType value 
     */ 
    public void setUndefined(UITargetObjectType discriminator) {
        _discriminator = discriminator;
        _object = null;
    }

    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) {
            return false;
        }
        if(!(o instanceof UITargetObject)) {
            return false;
        } else {
            UITargetObject uITargetObject= (UITargetObject)o;
            if(!(this._object.equals(uITargetObject._object))){
                return false;
            } else {
                if(!(this._discriminator.equals(uITargetObject._discriminator))){
                    return false;
                }
            }
            if (this.hashCode() != o.hashCode()) {
                return false;
            }
            return true;
        }
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // UITargetObject

