//Source file: UIVariableInfo.java
//Date: June 2005
//User Interaction Data Types for 3GPP TS 29.198-05 V5.10.0

package org.csapi.jr.se.ui;

/**
 * Defines the Tagged Choice of Data Elements that specify the variable parts in the information to send to the user.
 *
 */
public final class UIVariableInfo implements java.io.Serializable {

    private UIVariablePartType _discriminator = null;
    private java.lang.Object _object;

    /**
     * Creates a new UIVariableInfo.
     * Tagged choice of data elements always have empty constructors
     */ 
    public UIVariableInfo() {}

    /**
     * This method returns the discriminator.
     * 
     * @return a UIVariablePartType value 
     * @exception InvalidUnionAccessorException if an error occurs 
     */ 
    public UIVariablePartType getDiscriminator() throws org.csapi.jr.se.InvalidUnionAccessorException {
        if (_discriminator == null) {
            throw new org.csapi.jr.se.InvalidUnionAccessorException();
        }
        return _discriminator;
    }

    /**
     * This method returns a VariablePartInteger
     * 
     * @return  a int value
     * @exception InvalidUnionAccessorException if an error occurs 
     */
    public int getVariablePartInteger() throws org.csapi.jr.se.InvalidUnionAccessorException {
        if (_discriminator != UIVariablePartType.UI_VARIABLE_PART_INT) {
            throw new org.csapi.jr.se.InvalidUnionAccessorException();
        }
        return (((java.lang.Integer) _object).intValue());
    }

    /**
     * This method sets a VariablePartInteger
     * 
     * @param value a int value
     */
    public void setVariablePartInteger(int value) {
        _discriminator = UIVariablePartType.UI_VARIABLE_PART_INT;
        _object = new java.lang.Integer(value);
    }

    /**
     * This method returns a VariablePartAddress
     * 
     * @return  a java.lang.String value
     * @exception InvalidUnionAccessorException if an error occurs 
     */
    public java.lang.String getVariablePartAddress() throws org.csapi.jr.se.InvalidUnionAccessorException {
        if (_discriminator != UIVariablePartType.UI_VARIABLE_PART_ADDRESS) {
            throw new org.csapi.jr.se.InvalidUnionAccessorException();
        }
        return (((java.lang.String) _object));
    }

    /**
     * This method sets a VariablePartAddress
     * 
     * @param value a java.lang.String value
     */
    public void setVariablePartAddress(java.lang.String value) {
        _discriminator = UIVariablePartType.UI_VARIABLE_PART_ADDRESS;
        _object = value;
    }

    /**
     * This method returns a VariablePartTime
     * 
     * @return  a java.lang.String value
     * @exception InvalidUnionAccessorException if an error occurs 
     */
    public java.lang.String getVariablePartTime() throws org.csapi.jr.se.InvalidUnionAccessorException {
        if (_discriminator != UIVariablePartType.UI_VARIABLE_PART_TIME) {
            throw new org.csapi.jr.se.InvalidUnionAccessorException();
        }
        return (((java.lang.String) _object));
    }

    /**
     * This method sets a VariablePartTime
     * 
     * @param value a java.lang.String value
     */
    public void setVariablePartTime(java.lang.String value) {
        _discriminator = UIVariablePartType.UI_VARIABLE_PART_TIME;
        _object = value;
    }

    /**
     * This method returns a VariablePartDate
     * 
     * @return  a java.lang.String value
     * @exception InvalidUnionAccessorException if an error occurs 
     */
    public java.lang.String getVariablePartDate() throws org.csapi.jr.se.InvalidUnionAccessorException {
        if (_discriminator != UIVariablePartType.UI_VARIABLE_PART_DATE) {
            throw new org.csapi.jr.se.InvalidUnionAccessorException();
        }
        return (((java.lang.String) _object));
    }

    /**
     * This method sets a VariablePartDate
     * 
     * @param value a java.lang.String value
     */
    public void setVariablePartDate(java.lang.String value) {
        _discriminator = UIVariablePartType.UI_VARIABLE_PART_DATE;
        _object = value;
    }

    /**
     * This method returns a VariablePartPrice
     * 
     * @return  a java.lang.String value
     * @exception InvalidUnionAccessorException if an error occurs 
     */
    public java.lang.String getVariablePartPrice() throws org.csapi.jr.se.InvalidUnionAccessorException {
        if (_discriminator != UIVariablePartType.UI_VARIABLE_PART_PRICE) {
            throw new org.csapi.jr.se.InvalidUnionAccessorException();
        }
        return (((java.lang.String) _object));
    }

    /**
     * This method sets a VariablePartPrice
     * 
     * @param value a java.lang.String value
     */
    public void setVariablePartPrice(java.lang.String value) {
        _discriminator = UIVariablePartType.UI_VARIABLE_PART_PRICE;
        _object = value;
    }


    /**
     * This method will receive the discriminator as a parameter and will set _object to null
     * 
     * @param discriminator a UIVariablePartType value 
     */ 
    public void setUndefined(UIVariablePartType discriminator) {
        _discriminator = discriminator;
        _object = null;
    }

    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) {
            return false;
        }
        if(!(o instanceof UIVariableInfo)) {
            return false;
        } else {
            UIVariableInfo uIVariableInfo= (UIVariableInfo)o;
            if(!(this._object.equals(uIVariableInfo._object))){
                return false;
            } else {
                if(!(this._discriminator.equals(uIVariableInfo._discriminator))){
                    return false;
                }
            }
            if (this.hashCode() != o.hashCode()) {
                return false;
            }
            return true;
        }
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // UIVariableInfo

