//Source file: UIVariablePartType.java
//Date: June 2005
//User Interaction Data Types for 3GPP TS 29.198-05 V5.10.0

package org.csapi.jr.se.ui;

/**
 * Defines the type of the variable parts in the information to send to the user.
 *
 */
public final class UIVariablePartType implements java.io.Serializable {

    private int _value;
    private static int _size = 5;
    private static UIVariablePartType[] _array = new UIVariablePartType[_size];

    /**
     * Private constructor used internally to construct static objects 
     */
    private UIVariablePartType(int value) {
        _value = value;
        _array[_value] = this;
    }

    /**
     * Variable part is of type integer
     */
    public static final int _UI_VARIABLE_PART_INT =  0;

    /**
     * Variable part is of type integer
     */
    public static final UIVariablePartType UI_VARIABLE_PART_INT = new UIVariablePartType(_UI_VARIABLE_PART_INT);

    /**
     * Variable part is of type address
     */
    public static final int _UI_VARIABLE_PART_ADDRESS =  1;

    /**
     * Variable part is of type address
     */
    public static final UIVariablePartType UI_VARIABLE_PART_ADDRESS = new UIVariablePartType(_UI_VARIABLE_PART_ADDRESS);

    /**
     * Variable part is of type time
     */
    public static final int _UI_VARIABLE_PART_TIME =  2;

    /**
     * Variable part is of type time
     */
    public static final UIVariablePartType UI_VARIABLE_PART_TIME = new UIVariablePartType(_UI_VARIABLE_PART_TIME);

    /**
     * Variable part is of type date
     */
    public static final int _UI_VARIABLE_PART_DATE =  3;

    /**
     * Variable part is of type date
     */
    public static final UIVariablePartType UI_VARIABLE_PART_DATE = new UIVariablePartType(_UI_VARIABLE_PART_DATE);

    /**
     * Variable part is of type price
     */
    public static final int _UI_VARIABLE_PART_PRICE =  4;

    /**
     * Variable part is of type price
     */
    public static final UIVariablePartType UI_VARIABLE_PART_PRICE = new UIVariablePartType(_UI_VARIABLE_PART_PRICE);


    /**
     * Method allows class to replace/resolve the object read from the stream before it 
     * is returned to the caller. By implementing this method, a class can directly control
     * the types and instances of its own instances being deserialized.
     *
     * @return the resolved UIVariablePartType object 
     */
    private Object readResolve() throws java.io.ObjectStreamException {
        return _array[_value];
    }

    /**
     * Number representing enum type
     *
     * @return int number representing type of object, this is defined within the class
     */
    public int getValue() {
        return _value;
    }

    /**
     * getValueText method, overrides the getValueText() method in class java.lang.Object
     *
     * @return String  The stringified version of the UIVariablePartType object
     */
    public String getValueText() {
        switch (_value) {
            case _UI_VARIABLE_PART_INT:
                return "UI_VARIABLE_PART_INT";
            case _UI_VARIABLE_PART_ADDRESS:
                return "UI_VARIABLE_PART_ADDRESS";
            case _UI_VARIABLE_PART_TIME:
                return "UI_VARIABLE_PART_TIME";
            case _UI_VARIABLE_PART_DATE:
                return "UI_VARIABLE_PART_DATE";
            case _UI_VARIABLE_PART_PRICE:
                return "UI_VARIABLE_PART_PRICE";
            default:
                return "ERROR";
        }
    }

    /**
     * Accepts values in the range of 0 to 4
     *
     * @param value number representing type of object, this is defined within the class
     * @throws org.csapi.jr.se.InvalidEnumValueException thrown if invalid value is passed into method
     */
    public static UIVariablePartType getObject(int value) throws org.csapi.jr.se.InvalidEnumValueException {
        if(value >= 0 && value < _size) {
            return _array[value];
        } else {
            throw new org.csapi.jr.se.InvalidEnumValueException("value [" + value +" ] out of range");
        }
    }

    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof UIVariablePartType)) {
            return false;
        }
        UIVariablePartType uIVariablePartType = (UIVariablePartType) o; 
        if(!(this.getValue() == uIVariablePartType.getValue())) {
            return false;
        }
        if (this.hashCode() != uIVariablePartType.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // UIVariablePartType

